.. py:function:: sf_coupling_6j(two_ja, two_jb, two_jc, two_jd, two_je, two_jf [, ret])

    Wrapper for :c:func:`gsl_sf_coupling_6j`
    c code signature: double gsl_sf_coupling_6j( int two_ja,  int two_jb,  int two_jc,  int two_jd,  int two_je,  int two_jf)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_l_l_l_l__Rd__O`
    
    :param int two_ja: positional argument 0
    :param int two_jb: positional argument 1
    :param int two_jc: positional argument 2
    :param int two_jd: positional argument 3
    :param int two_je: positional argument 4
    :param int two_jf: positional argument 5
    :param double ret: positional argument 6
    :rtype:  double 
    :return: result 

.. py:function:: sf_coupling_9j(two_ja, two_jb, two_jc, two_jd, two_je, two_jf, two_jg, two_jh, two_ji [, ret])

    Wrapper for :c:func:`gsl_sf_coupling_9j`
    c code signature: double gsl_sf_coupling_9j( int two_ja,  int two_jb,  int two_jc,  int two_jd,  int two_je,  int two_jf,  int two_jg,  int two_jh,  int two_ji)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_l_l_l_l_l_l_l__Rd__O`
    
    :param int two_ja: positional argument 0
    :param int two_jb: positional argument 1
    :param int two_jc: positional argument 2
    :param int two_jd: positional argument 3
    :param int two_je: positional argument 4
    :param int two_jf: positional argument 5
    :param int two_jg: positional argument 6
    :param int two_jh: positional argument 7
    :param int two_ji: positional argument 8
    :param double ret: positional argument 9
    :rtype:  double 
    :return: result 

.. py:function:: sf_coupling_6j_e(two_ja, two_jb, two_jc, two_jd, two_je, two_jf [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_coupling_6j_e`
    c code signature: int gsl_sf_coupling_6j_e( int two_ja,  int two_jb,  int two_jc,  int two_jd,  int two_je,  int two_jf, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_l_l_l_l__Rl__Ord`
    
    :param int two_ja: positional argument 0
    :param int two_jb: positional argument 1
    :param int two_jc: positional argument 2
    :param int two_jd: positional argument 3
    :param int two_je: positional argument 4
    :param int two_jf: positional argument 5
    :param int ret: positional argument 6
    :param double result.val: positional argument 7
    :param double result.err: positional argument 8
    :rtype:  tuple(:param int ret: positional argument 6, :param double result.val: positional argument 7, :param double result.err: positional argument 8) 
    :return: result 

.. py:function:: sf_coupling_RacahW(two_ja, two_jb, two_jc, two_jd, two_je, two_jf [, ret])

    Wrapper for :c:func:`gsl_sf_coupling_RacahW`
    c code signature: double gsl_sf_coupling_RacahW( int two_ja,  int two_jb,  int two_jc,  int two_jd,  int two_je,  int two_jf)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_l_l_l_l__Rd__O`
    
    :param int two_ja: positional argument 0
    :param int two_jb: positional argument 1
    :param int two_jc: positional argument 2
    :param int two_jd: positional argument 3
    :param int two_je: positional argument 4
    :param int two_jf: positional argument 5
    :param double ret: positional argument 6
    :rtype:  double 
    :return: result 

.. py:function:: sf_coupling_9j_e(two_ja, two_jb, two_jc, two_jd, two_je, two_jf, two_jg, two_jh, two_ji [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_coupling_9j_e`
    c code signature: int gsl_sf_coupling_9j_e( int two_ja,  int two_jb,  int two_jc,  int two_jd,  int two_je,  int two_jf,  int two_jg,  int two_jh,  int two_ji, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_l_l_l_l_l_l_l__Rl__Ord`
    
    :param int two_ja: positional argument 0
    :param int two_jb: positional argument 1
    :param int two_jc: positional argument 2
    :param int two_jd: positional argument 3
    :param int two_je: positional argument 4
    :param int two_jf: positional argument 5
    :param int two_jg: positional argument 6
    :param int two_jh: positional argument 7
    :param int two_ji: positional argument 8
    :param int ret: positional argument 9
    :param double result.val: positional argument 10
    :param double result.err: positional argument 11
    :rtype:  tuple(:param int ret: positional argument 9, :param double result.val: positional argument 10, :param double result.err: positional argument 11) 
    :return: result 

.. py:function:: sf_coupling_RacahW_e(two_ja, two_jb, two_jc, two_jd, two_je, two_jf [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_coupling_RacahW_e`
    c code signature: int gsl_sf_coupling_RacahW_e( int two_ja,  int two_jb,  int two_jc,  int two_jd,  int two_je,  int two_jf, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_l_l_l_l__Rl__Ord`
    
    :param int two_ja: positional argument 0
    :param int two_jb: positional argument 1
    :param int two_jc: positional argument 2
    :param int two_jd: positional argument 3
    :param int two_je: positional argument 4
    :param int two_jf: positional argument 5
    :param int ret: positional argument 6
    :param double result.val: positional argument 7
    :param double result.err: positional argument 8
    :rtype:  tuple(:param int ret: positional argument 6, :param double result.val: positional argument 7, :param double result.err: positional argument 8) 
    :return: result 

.. py:function:: sf_coupling_3j(two_ja, two_jb, two_jc, two_ma, two_mb, two_mc [, ret])

    Wrapper for :c:func:`gsl_sf_coupling_3j`
    c code signature: double gsl_sf_coupling_3j( int two_ja,  int two_jb,  int two_jc,  int two_ma,  int two_mb,  int two_mc)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_l_l_l_l__Rd__O`
    
    :param int two_ja: positional argument 0
    :param int two_jb: positional argument 1
    :param int two_jc: positional argument 2
    :param int two_ma: positional argument 3
    :param int two_mb: positional argument 4
    :param int two_mc: positional argument 5
    :param double ret: positional argument 6
    :rtype:  double 
    :return: result 

.. py:function:: sf_coupling_3j_e(two_ja, two_jb, two_jc, two_ma, two_mb, two_mc [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_coupling_3j_e`
    c code signature: int gsl_sf_coupling_3j_e( int two_ja,  int two_jb,  int two_jc,  int two_ma,  int two_mb,  int two_mc, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_l_l_l_l_l__Rl__Ord`
    
    :param int two_ja: positional argument 0
    :param int two_jb: positional argument 1
    :param int two_jc: positional argument 2
    :param int two_ma: positional argument 3
    :param int two_mb: positional argument 4
    :param int two_mc: positional argument 5
    :param int ret: positional argument 6
    :param double result.val: positional argument 7
    :param double result.err: positional argument 8
    :rtype:  tuple(:param int ret: positional argument 6, :param double result.val: positional argument 7, :param double result.err: positional argument 8) 
    :return: result 

